==> kboincspy_0.9.0.orig.tar.gz: kboincspy-0.9.0.orig/src/monitors/seti/kbssetitaskmonitor.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Roberto Virga                                   *
 *   rvirga@users.sf.net                                                   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KBSSETITASKMONITOR_H
#define KBSSETITASKMONITOR_H

#include <kbstaskmonitor.h>

#include "setidata.h"

class KBSSETITaskMonitor : public KBSTaskMonitor
{
  Q_OBJECT
  public:
    KBSSETITaskMonitor(unsigned task, KBSBOINCMonitor *parent, const char *name=0);
    virtual ~KBSSETITaskMonitor();
    
    virtual const SETIState *state() const;
  
  protected:
    virtual bool parseFile(KBSFileInfo *file, const QString &fileName);
    
  private:
    bool parseStateDocument(const QDomDocument &document);
    void logCalibrationPair();
        
  private slots:
    void updateFile(const QString &fileName);
    
  protected:
    SETIState m_state;
};

#endif

==> kboincspy_0.9.1.orig.tar.gz: kboincspy-0.9.1.orig/src/monitors/seti/kbssetitaskmonitor.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Roberto Virga                                   *
 *   rvirga@users.sourceforge.net                                          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef KBSSETITASKMONITOR_H
#define KBSSETITASKMONITOR_H

#include <kbstaskmonitor.h>

#include <kbssetidata.h>

class KBSSETITaskMonitor : public KBSTaskMonitor
{
  Q_OBJECT
  public:
    KBSSETITaskMonitor(unsigned task, KBSBOINCMonitor *parent, const char *name=0);
    virtual ~KBSSETITaskMonitor();
    
    virtual const KBSSETIState *state() const;
  
  protected:
    virtual bool parseFile(KBSFileInfo *file, const QString &fileName);
  
  private:
    bool parseStateDocument(const QDomDocument &document);
    void logCalibrationPair();
  
  private slots:
    void updateFile(const QString &fileName);
  
  protected:
    KBSSETIState m_state;
};

#endif
